Struct Millisecond
struct Millisecond
A unit of time representing exactly one millisecond.
Implementations
impl Millisecond
const fn per<T>(_larger: T) -> <T as DefaultOutput<Self>>::Output where T: MultipleOf<Self, <T as >::Output> + DefaultOutput<Self> + CopyObtain the number of times
Millisecondcan fit intoT. IfTis smaller thanMillisecond, the code will fail to compile. The return type is the smallest unsigned integer type that can represent the value.Valid calls:
Millisecond::per(Millisecond)(returnsu8)Millisecond::per(Second)(returnsu16)Millisecond::per(Minute)(returnsu16)Millisecond::per(Hour)(returnsu32)Millisecond::per(Day)(returnsu32)Millisecond::per(Week)(returnsu32)
const fn per_t<Output, impl MultipleOf<Self, Output> + Copy: MultipleOf<Self, Output> + Copy>(larger: impl MultipleOf<Self, Output> + Copy) -> OutputObtain the number of times
Millisecondcan fit intoT. IfTis smaller thanMillisecond, the code will fail to compile. The return type is any primitive numeric type that can represent the value.Valid calls:
Millisecond::per(Millisecond)(returnsu8,u16,u32,u64,u128,usize,i8,i16,i32,i64,i128,isize,f32, orf64)Millisecond::per(Second)(returnsu16,u32,u64,u128,usize,i16,i32,i64,i128,isize,f32, orf64)Millisecond::per(Minute)(returnsu16,u32,u64,u128,usize,i32,i64,i128,isize,f32, orf64)Millisecond::per(Hour)(returnsu32,u64,u128,usize,i32,i64,i128,isize,f32, orf64)Millisecond::per(Day)(returnsu32,u64,u128,usize,i32,i64,i128,isize,f32, orf64)Millisecond::per(Week)(returnsu32,u64,u128,usize,i32,i64,i128,isize,f32, orf64)
impl Clone for Millisecond
fn clone(self: &Self) -> Millisecond
impl Copy for Millisecond
impl Debug for Millisecond
fn fmt(self: &Self, f: &mut Formatter<'_>) -> Result
impl Freeze for Millisecond
impl RefUnwindSafe for Millisecond
impl Send for Millisecond
impl Sync for Millisecond
impl Unpin for Millisecond
impl UnsafeUnpin for Millisecond
impl UnwindSafe for Millisecond
impl<T> Any for Millisecond
fn type_id(self: &Self) -> TypeId
impl<T> Borrow for Millisecond
fn borrow(self: &Self) -> &T
impl<T> BorrowMut for Millisecond
fn borrow_mut(self: &mut Self) -> &mut T
impl<T> CloneToUninit for Millisecond
unsafe fn clone_to_uninit(self: &Self, dest: *mut u8)
impl<T> From for Millisecond
fn from(t: T) -> TReturns the argument unchanged.
impl<T, U> Into for Millisecond
fn into(self: Self) -> UCalls
U::from(self).That is, this conversion is whatever the implementation of
[From]<T> for Uchooses to do.
impl<T, U> TryFrom for Millisecond
fn try_from(value: U) -> Result<T, <T as TryFrom<U>>::Error>
impl<T, U> TryInto for Millisecond
fn try_into(self: Self) -> Result<U, <U as TryFrom<T>>::Error>