Function days_in_month_leap

const fn days_in_month_leap(month: u8, is_leap_year: bool) -> u8

Get the number of days in the month. The year does not need to be known, but whether the year is a leap year does.

Note: This function is not exposed by the time crate. It is an implementation detail.