Struct Hour
struct Hour
A unit of time representing exactly one hour.
Implementations
impl Hour
const fn per<T>(_larger: T) -> <T as DefaultOutput<Self>>::Output where T: MultipleOf<Self, <T as >::Output> + DefaultOutput<Self> + CopyObtain the number of times
Hourcan fit intoT. IfTis smaller thanHour, the code will fail to compile. The return type is the smallest unsigned integer type that can represent the value.Valid calls:
Hour::per(Hour)(returnsu8)Hour::per(Day)(returnsu8)Hour::per(Week)(returnsu8)
const fn per_t<Output, impl MultipleOf<Self, Output> + Copy: MultipleOf<Self, Output> + Copy>(larger: impl MultipleOf<Self, Output> + Copy) -> OutputObtain the number of times
Hourcan fit intoT. IfTis smaller thanHour, the code will fail to compile. The return type is any primitive numeric type that can represent the value.Valid calls:
Hour::per(Hour)(returnsu8,u16,u32,u64,u128,usize,i8,i16,i32,i64,i128,isize,f32, orf64)Hour::per(Day)(returnsu8,u16,u32,u64,u128,usize,i8,i16,i32,i64,i128,isize,f32, orf64)Hour::per(Week)(returnsu8,u16,u32,u64,u128,usize,i16,i32,i64,i128,isize,f32, orf64)
impl Clone for Hour
fn clone(self: &Self) -> Hour
impl Copy for Hour
impl Debug for Hour
fn fmt(self: &Self, f: &mut Formatter<'_>) -> Result
impl Freeze for Hour
impl RefUnwindSafe for Hour
impl Send for Hour
impl Sync for Hour
impl Unpin for Hour
impl UnsafeUnpin for Hour
impl UnwindSafe for Hour
impl<T> Any for Hour
fn type_id(self: &Self) -> TypeId
impl<T> Borrow for Hour
fn borrow(self: &Self) -> &T
impl<T> BorrowMut for Hour
fn borrow_mut(self: &mut Self) -> &mut T
impl<T> CloneToUninit for Hour
unsafe fn clone_to_uninit(self: &Self, dest: *mut u8)
impl<T> From for Hour
fn from(t: T) -> TReturns the argument unchanged.
impl<T, U> Into for Hour
fn into(self: Self) -> UCalls
U::from(self).That is, this conversion is whatever the implementation of
[From]<T> for Uchooses to do.
impl<T, U> TryFrom for Hour
fn try_from(value: U) -> Result<T, <T as TryFrom<U>>::Error>
impl<T, U> TryInto for Hour
fn try_into(self: Self) -> Result<U, <U as TryFrom<T>>::Error>