Struct Minute
struct Minute
A unit of time representing exactly one minute.
Implementations
impl Minute
const fn per<T>(_larger: T) -> <T as DefaultOutput<Self>>::Output where T: MultipleOf<Self, <T as >::Output> + DefaultOutput<Self> + CopyObtain the number of times
Minutecan fit intoT. IfTis smaller thanMinute, the code will fail to compile. The return type is the smallest unsigned integer type that can represent the value.Valid calls:
Minute::per(Minute)(returnsu8)Minute::per(Hour)(returnsu8)Minute::per(Day)(returnsu16)Minute::per(Week)(returnsu16)
const fn per_t<Output, impl MultipleOf<Self, Output> + Copy: MultipleOf<Self, Output> + Copy>(larger: impl MultipleOf<Self, Output> + Copy) -> OutputObtain the number of times
Minutecan fit intoT. IfTis smaller thanMinute, the code will fail to compile. The return type is any primitive numeric type that can represent the value.Valid calls:
Minute::per(Minute)(returnsu8,u16,u32,u64,u128,usize,i8,i16,i32,i64,i128,isize,f32, orf64)Minute::per(Hour)(returnsu8,u16,u32,u64,u128,usize,i8,i16,i32,i64,i128,isize,f32, orf64)Minute::per(Day)(returnsu16,u32,u64,u128,usize,i16,i32,i64,i128,isize,f32, orf64)Minute::per(Week)(returnsu16,u32,u64,u128,usize,i16,i32,i64,i128,isize,f32, orf64)
impl Clone for Minute
fn clone(self: &Self) -> Minute
impl Copy for Minute
impl Debug for Minute
fn fmt(self: &Self, f: &mut Formatter<'_>) -> Result
impl Freeze for Minute
impl RefUnwindSafe for Minute
impl Send for Minute
impl Sync for Minute
impl Unpin for Minute
impl UnsafeUnpin for Minute
impl UnwindSafe for Minute
impl<T> Any for Minute
fn type_id(self: &Self) -> TypeId
impl<T> Borrow for Minute
fn borrow(self: &Self) -> &T
impl<T> BorrowMut for Minute
fn borrow_mut(self: &mut Self) -> &mut T
impl<T> CloneToUninit for Minute
unsafe fn clone_to_uninit(self: &Self, dest: *mut u8)
impl<T> From for Minute
fn from(t: T) -> TReturns the argument unchanged.
impl<T, U> Into for Minute
fn into(self: Self) -> UCalls
U::from(self).That is, this conversion is whatever the implementation of
[From]<T> for Uchooses to do.
impl<T, U> TryFrom for Minute
fn try_from(value: U) -> Result<T, <T as TryFrom<U>>::Error>
impl<T, U> TryInto for Minute
fn try_into(self: Self) -> Result<U, <U as TryFrom<T>>::Error>