Function days_in_month
const fn days_in_month(month: u8, year: i32) -> u8
Get the number of days in the month of a given year.
# use days_in_month;
assert_eq!;
Note: This function is not exposed by the time crate. It is an implementation detail.